@@ -2,7 +2,8 @@
  * AT-SPI - Assistive Technology Service Provider Interface
  * (Gnome Accessibility Project; http://developer.gnome.org/projects/gap)
  *
- * Copyright 2001 Sun Microsystems Inc.
+ * Copyright 2001, 2002 Sun Microsystems Inc.,
+ * Copyright 2001, 2002 Ximian, Inc.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -57,7 +58,7 @@ impl_getKeyBinding (PortableServer_Servant servant,
 BONOBO_TYPE_FUNC_FULL (SpiAction,
 		       Accessibility_Action,
 		       SPI_TYPE_BASE,
-		       spi_action);
+		       spi_action)
 
 static void
 spi_action_class_init (SpiActionClass *klass)
@@ -102,7 +103,7 @@ impl__get_nActions (PortableServer_Servant servant,
 		    CORBA_Environment     *ev)
 {
   AtkAction *action = get_action_from_servant (servant);
-  return (CORBA_long) atk_action_get_n_actions (action);
+  return atk_action_get_n_actions (action);
 }
 
 static CORBA_boolean
@@ -110,7 +111,7 @@ impl_doAction (PortableServer_Servant servant,
 	       const CORBA_long index, CORBA_Environment * ev)
 {
   AtkAction *action = get_action_from_servant (servant);
-  return (CORBA_boolean) atk_action_do_action (action, (gint) index);
+  return atk_action_do_action (action, (gint) index);
 }
 
 static CORBA_string
@@ -121,7 +122,7 @@ impl_getDescription (PortableServer_Servant servant,
   AtkAction *action = get_action_from_servant (servant);
   const gchar *rv;
   
-  rv = atk_action_get_description (action, (gint) index);
+  rv = atk_action_get_description (action, index);
   if (rv)
     return CORBA_string_dup (rv);
   else
@@ -136,7 +137,7 @@ impl_getName (PortableServer_Servant servant,
   AtkAction *action = get_action_from_servant (servant);
   const gchar *rv;
   
-  rv = atk_action_get_name (action, (gint) index);
+  rv = atk_action_get_name (action, index);
   if (rv)
     return CORBA_string_dup (rv);
   else
@@ -151,7 +152,7 @@ impl_getKeyBinding (PortableServer_Servant servant,
   AtkAction *action = get_action_from_servant (servant);
   const gchar *rv;
   
-  rv = atk_action_get_keybinding (action, (gint) index);
+  rv = atk_action_get_keybinding (action, index);
   if (rv)
     return CORBA_string_dup (rv);
   else
